<?php
	if ( ! defined( 'ABSPATH' ) ) {
		exit; // Exit if accessed directly.
	}

	if ( ! class_exists( 'WP_List_Table' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
	}

	if ( ! class_exists( 'GooglePlacesApiService' ) ) {
		require_once( ZLEADSCRM_PROSPECT_PLUGIN_DIR . 'helper/google-places-api/GooglePlacesApiService.php' );
	}

	class ZLEADSCRM_PROSPECT_Core_Leads_Result extends WP_List_Table {

		private $query_params;

		private $error = '';

		private $next_page_token = '';

		private $current_page_number;

		public function __construct( $query_params ) {
			$this->items           = [];
			$this->query_params    = $query_params;
			$this->next_page_token = $this->get_next_page_token();
			parent::__construct(
				array(
					'singular' => 'lead_result',
					'plural'   => 'lead_results',
					'ajax'     => false,
				)
			);
		}

		public function print_overview() {
			$this->prepare_items();
			echo '<div class="zleadscrm_overview_wrap">';
			echo '<h2 class="screen-reader-text">Leads Results List</h2>';
			if ( $this->error != '' ) {
				echo '<div>';
				echo '<h3>' . $this->error . '</h3>';
				echo '</div>';
			} else {
				if ( count( $this->items ) != 0 ) {
					if ( class_exists( 'ZLEADSCRM_EXPORT_Core' ) ) {
						if ( zleadscrm_user_can_export_search( get_current_user_id() ) ) {
							echo '<ul class="subsubsub">';
							echo '<li>';
							echo '<a href="data:text/csv;charset=utf-8,' . $this->get_export_data() . '" download="export.csv"  class="button button-default" style="margin-left: 5px; margin-top: -5px; margin-bottom: 5px;">Export</a>';
							echo '</li>';
							echo '</ul>';

						}
					}
					$this->display();
				}
			}
			echo '</div>';
		}

		public function column_default( $result, $column_name ) {
			$current_user_id = get_current_user_id();
			if ( zleadscrm_user_can_do_advanced_search( $current_user_id ) ) {
				switch ( $column_name ) {
					case 'business_name':
						return '<span>' . $result['business_name'] . '</span>';
					case 'business_type':
						$o = '';
						if ( is_array( $result['business_type'] ) ) {
							foreach ( $result['business_type'] as $btype ) {
								$o .= '<span>' . ucfirst( str_replace( '_', ' ', $btype ) ) . '</span><br/>';
							}
						} else {
							$arr = explode( ';', $result['business_type'] );
							foreach ( $arr as $btype ) {
								$o .= '<span>' . ucfirst( str_replace( '_', ' ', $btype ) ) . '</span><br/>';
							}
						}

						return $o;
					case 'phone':
						return '<span>' . $result['phone'] . '</span>';
					case 'website':
						return '<a target="_blank" href="' . $result['website'] . '">' . $result['website'] . '</a>';
					case 'address':
						return '<span>' . $result['address'] . '</span>';
					case 'actions':
						ob_start();
						?><p>
						<?php

						$data = '';
						$data .= str_replace( '#', 'no. ', $result['business_name'] ) . '~';
						$o    = '';
						if ( is_array( $result['business_type'] ) ) {
							foreach ( $result['business_type'] as $btype ) {
								$o .= ucfirst( str_replace( '_', ' ', $btype ) ) . ';';
							}
						} else {
							$o .= $result['business_type'];
						}
						$data  .= $o . '~';
						$data  .= str_replace( '#', '', $result['phone'] ) . '~';
						$data  .= str_replace( '#', '', $result['website'] ) . '~';
						$data  .= str_replace( '#', 'no. ', $result['address'] ) . '~';
						$owner = get_current_user_id() . '~';
						$data  .= $owner;
						$url   = $result['url'];
						$data  .= $url;


						$is_bookmarked = $this->is_bookmarked( $result ) == true ? 'true' : 'false';

						$bookmark = array(
							'data-link'          => admin_url( 'admin-ajax.php' ),
							'data-info'          => $data,
							'data-is-bookmarked' => $is_bookmarked
						);
						printf( '<a class="button dashicons dashicons-star-' . ( $bookmark['data-is-bookmarked'] == 'true' ? 'filled' : 'empty' ) . ' lead_modify_bookmark" data-tip="Bookmark" data-link="%s" data-info="%s" data-is-bookmarked="%s" style="width: 35px;"></a>', esc_url( $bookmark['data-link'] ), $bookmark['data-info'], $bookmark['data-is-bookmarked'] );

						$actions['maps'] = array(
							'url'    => $url,
							'name'   => 'Maps',
							'action' => 'maps',
							'class'  => 'location'
						);

						$search_link = str_replace( ' ', '+', $result['business_name'] );

						$actions['search'] = array(
							'url'    => 'https://www.google.com/search?q=' . $search_link,
							'name'   => 'Search',
							'action' => 'search',
							'class'  => 'search'
						);

						foreach ( $actions as $action ) {
							printf( '<a class="button tips dashicons dashicons-%s" href="%s" target="_blank" style="width: 35px;"></a>', esc_attr( $action['class'] ), esc_url( $action['url'] ) );
						}
						?>
                        </p>
						<?php
						$result_actions = ob_get_contents();
						ob_end_clean();

						return $result_actions;
				}
			} else {
				if ( zleadscrm_user_can_do_basic_search( $current_user_id ) ) {
					switch ( $column_name ) {
						case 'business_name':
							return '<span>' . $result['business_name'] . '</span>';
						case 'business_type':
							$o = '';
							if ( is_array( $result['business_type'] ) ) {

								foreach ( $result['business_type'] as $btype ) {
									$o .= '<span>' . ucfirst( str_replace( '_', ' ', $btype ) ) . '</span><br/>';
								}
							} else {
								$arr = explode( ';', $result['business_type'] );
								foreach ( $arr as $btype ) {
									$o .= '<span>' . ucfirst( str_replace( '_', ' ', $btype ) ) . '</span><br/>';
								}
							}

							return $o;
						case 'address':
							return '<span>' . $result['address'] . '</span>';
						case 'actions':
							ob_start();
							?><p>
							<?php

							$data = '';
							$data .= str_replace( '#', 'no. ', $result['business_name'] ) . '~';
							$o    = '';
							if ( is_array( $result['business_type'] ) ) {
								foreach ( $result['business_type'] as $btype ) {
									$o .= ucfirst( str_replace( '_', ' ', $btype ) ) . ';';
								}
							} else {
								$o .= $result['business_type'];
							}

							$data  .= $o . '~';
							$data  .= $result['address'] . '~';
							$owner = get_current_user_id() . '~';
							$data  .= $owner . '~';
							$url   = $result['url'];
							$data  .= $url;


							$is_bookmarked = $this->is_bookmarked( $result ) == true ? 'true' : 'false';

							$bookmark = array(
								'data-link'          => admin_url( 'admin-ajax.php' ),
								'data-info'          => $data,
								'data-is-bookmarked' => $is_bookmarked
							);
							printf( '<a class="button dashicons dashicons-star-' . ( $bookmark['data-is-bookmarked'] == 'true' ? 'filled' : 'empty' ) . ' lead_modify_bookmark" data-tip="Bookmark" data-link="%s" data-info="%s" data-is-bookmarked="%s" style="width: 35px;"></a>', esc_url( $bookmark['data-link'] ), esc_attr( $bookmark['data-info'] ), esc_attr( $bookmark['data-is-bookmarked'] ) );

							$actions['maps'] = array(
								'url'    => $url,
								'name'   => 'Maps',
								'action' => 'maps',
								'class'  => 'location'
							);

							$search_link = str_replace( ' ', '+', $result['business_name'] );

							$actions['search'] = array(
								'url'    => 'https://www.google.com/search?q=' . $search_link,
								'name'   => 'Search',
								'action' => 'search',
								'class'  => 'search'
							);

							foreach ( $actions as $action ) {
								printf( '<a class="button tips dashicons dashicons-%s" href="%s" target="_blank" style="width: 35px;"></a>', esc_attr( $action['class'] ), esc_url( $action['url'] ) );
							}
							?>
                            </p>
							<?php
							$result_actions = ob_get_contents();
							ob_end_clean();

							return $result_actions;
					}
				}
			}

			return '';
		}

		public function display_tablenav( $which ) {
			if ( $which == 'top' ) {

				$limit_number            = (int) get_option( 'zleadscrm_limit_call_number' );
				$total_number_of_results = $this->get_total_number_of_results();


				$o = '<div class="alignright actions bulkactions">';

				if ( $this->current_page_number != 1 ) {
					$o .= '<a style="margin-bottom:1rem;" id="zleadscrm_previous_page" class="prev-page button" data-current-page="' . esc_attr( $this->current_page_number ) . '" data-link="' . admin_url( 'admin-ajax.php' ) . '"><span class="screen-reader-text">Previous page</span><span aria-hidden="true">‹</span></a>';
				}

				if ( $total_number_of_results > 20 ) {
					$o .= '<div style="margin: 5px 5px 0 5px; display: inline-block; margin-bottom: 1rem;"><span style="background:#fff;border:1px solid #e6e6e6; padding: 5px 15px; color:#000;">' . esc_html( $this->current_page_number ) . '</span></div>';
				}

				if ( $this->current_page_number * 20 < $total_number_of_results ) {
					$o .= '<a style="margin-bottom:1rem;" id="zleadscrm_next_page" class="next-page button" data-current-page="' . esc_attr( $this->current_page_number ) . '" data-link="' . admin_url( 'admin-ajax.php' ) . '"><span class="screen-reader-text">Next page</span><span aria-hidden="true">›</span></a>';
				}


				if ( $this->get_next_page_token() != '' && $total_number_of_results <= $limit_number - 20 && $this->current_page_number * 20 == $total_number_of_results ) {
					$next_token = $this->get_next_page_token();
					$o          .= '<a style="margin-bottom:1rem;" id="zleadscrm_next_page_load" class="next-page button" data-next="' . esc_attr( $next_token ) . '" data-link="' . admin_url( 'admin-ajax.php' ) . '"><span class="screen-reader-text">Next page</span><span aria-hidden="true">Next page ›</span></a>';
				}


				$o .= '</div>';

				echo $o;
			} else {
				echo '<div style="margin-top: 1rem;">';
				if ( count( $this->items ) != 0 ) {
					if ( class_exists( 'ZLEADSCRM_EXPORT_Core' ) ) {

						if ( zleadscrm_user_can_export_search( get_current_user_id() ) ) {
							echo '<ul class="subsubsub">';
							echo '<li>';
							echo '<a href="data:text/csv;charset=utf-8,' . $this->get_export_data() . '" download="export.csv"  class="button button-default" style="margin-left: 5px; margin-top: -5px; margin-bottom: 5px;">Export</a>';
							echo '</li>';
							echo '</ul>';
						}
					}
				}

				$limit_number            = (int) get_option( 'zleadscrm_limit_call_number' );
				$total_number_of_results = $this->get_total_number_of_results();


				$o = '<div class="alignright actions bulkactions">';

				if ( $this->current_page_number != 1 ) {
					$o .= '<a id="zleadscrm_previous_page_bottom" class="prev-page button" data-current-page="' . esc_attr( $this->current_page_number ) . '" data-link="' . admin_url( 'admin-ajax.php' ) . '"><span class="screen-reader-text">Previous page</span><span aria-hidden="true">‹</span></a>';
				}

				if ( $total_number_of_results > 20 ) {
					$o .= '<div style="margin: 5px 5px 0 5px; display: inline-block;"><span style="background:#fff;border:1px solid #e6e6e6; padding: 5px 15px; color:#000;">' . esc_html( $this->current_page_number ) . '</span></div>';
				}

				if ( $this->current_page_number * 20 < $total_number_of_results ) {
					$o .= '<a id="zleadscrm_next_page_bottom" class="next-page button" data-current-page="' . esc_attr( $this->current_page_number ) . '" data-link="' . admin_url( 'admin-ajax.php' ) . '"><span class="screen-reader-text">Next page</span><span aria-hidden="true">›</span></a>';
				}

				if ( $this->get_next_page_token() != '' && $total_number_of_results <= $limit_number - 20 && $this->current_page_number * 20 == $total_number_of_results ) {
					$next_token = $this->get_next_page_token();
					$o          .= '<a id="zleadscrm_next_page_load_bottom" class="next-page button" data-next="' . esc_attr( $next_token ) . '" data-link="' . admin_url( 'admin-ajax.php' ) . '"><span class="screen-reader-text">Next page</span><span aria-hidden="true">Next page ›</span></a>';
				}


				$o .= '</div>';

				echo $o;
				echo '</div>';
			}
		}

		public function get_columns() {
			$current_user_id = get_current_user_id();
			$columns         = [];
			if ( zleadscrm_user_can_do_advanced_search( $current_user_id ) ) {

				$columns = array(
					'business_name' => 'Business Name',
					'business_type' => 'Business Type',
					'phone'         => 'Phone',
					'website'       => 'Website',
					'address'       => 'Address',
					'actions'       => 'Actions',
				);
			} else {
				if ( zleadscrm_user_can_do_basic_search( $current_user_id ) ) {
					$columns = array(
						'business_name' => 'Business Name',
						'business_type' => 'Business Type',
						'address'       => 'Address',
						'actions'       => 'Actions',
					);
				}
			}

			return $columns;
		}

		public function prepare_items() {
			global $wpdb;
			$table_name = $wpdb->prefix . 'zleadscrm_leads_results';

			$basic_request    = 0;
			$advanced_request = 0;
			$current_user_id  = get_current_user_id();

			/**
			 * Init column headers.
			 */
			$this->_column_headers = array( $this->get_columns(), array(), array() );


			if ( $_GET['zleadscrm_paged'] ) {
				$this->current_page_number = sanitize_text_field( $_GET['zleadscrm_paged'] );

				$items   = [];
				$offset  = ( (int) sanitize_text_field( $_GET['zleadscrm_paged'] ) - 1 ) * 20;
				$results = $wpdb->get_results( "SELECT * FROM $table_name WHERE user_id=$current_user_id ORDER BY timestamp ASC LIMIT 20 OFFSET $offset;" );
				if ( count( $results ) != 0 ) {
					foreach ( $results as $result ) {
						array_push( $items, array(
							'business_name' => $result->business_name,
							'business_type' => $result->business_type,
							'phone'         => $result->phone,
							'website'       => $result->website,
							'address'       => $result->address,
							'url'           => $result->url
						) );
					}
					$this->items = $items;
				} else {
					$this->items = [];
				}
			} else {
				if ( $this->query_params['current_page_token'] != '' ) {
					$google_api_key      = get_option( 'zleadscrm_google_places_api_key' );
					$googlePlacesService = new GooglePlacesApiService( $google_api_key );
					$request_result      = json_decode( $googlePlacesService->getNextPage( $this->query_params['current_page_token'] ) );
					if ( isset( $request_result->next_page_token ) ) {
						$this->set_next_page_token( $request_result->next_page_token );
					} else {
						$this->set_next_page_token( '' );
					}
					$name_search_results = $request_result->results;
					$name_items          = [];
					$basic_request ++;

					foreach ( $name_search_results as $result ) {
						if ( zleadscrm_user_can_do_advanced_search( $current_user_id )
						     && zleadscrm_can_do_more_advanced_searches_this_month( $current_user_id, count( $name_items ) )
						     && zleadscrm_can_do_more_advanced_searches_this_week( $current_user_id, count( $name_items ) ) ) {
							$detailed_request = json_decode( $googlePlacesService->getPlacesDetailsResults( $result->place_id ) );
							$detailed_result  = $detailed_request->result;
							$advanced_request ++;

							$item = array(
								'business_name' => $result->name,
								'business_type' => $result->types,
								'phone'         => $detailed_result->international_phone_number,
								'website'       => $detailed_result->website,
								'address'       => $detailed_result->formatted_address,
								'url'           => $detailed_result->url
							);
							zleadscrm_upload_new_lead_result( array(
								'timestamp'     => current_time( 'mysql' ),
								'user_id'       => get_current_user_id(),
								'business_name' => $item['business_name'],
								'business_type' => $item['business_type'],
								'phone'         => $item['phone'],
								'website'       => $item['website'],
								'address'       => $item['address'],
								'url'           => $item['url']
							) );
						} else {
							$address_request = json_decode( $googlePlacesService->getPlaceAddressAndUrl( $result->place_id ) );

							$item = array(
								'business_name' => $result->name,
								'business_type' => $result->types,
								'address'       => $address_request->result->formatted_address,
								'url'           => $address_request->result->url
							);
							zleadscrm_upload_new_lead_result( array(
								'timestamp'     => current_time( 'mysql' ),
								'user_id'       => get_current_user_id(),
								'business_name' => $item['business_name'],
								'business_type' => $item['business_type'],
								'url'           => $item['url'],
								'phone'         => '-',
								'website'       => '-',
								'address'       => $item['address']
							) );
						}
						array_push( $name_items, $item );

					}

					$this->items               = $name_items;
					$this->current_page_number = floor( $this->get_total_number_of_results() / 20 );
					$analytics                 = array(
						'user_id'           => $current_user_id,
						'basic_requests'    => $basic_request,
						'basic_results'     => count( $name_items ),
						'timestamp'         => current_time( 'Y-m-d' ),
						'advanced_requests' => 0,
						'advanced_results'  => 0
					);

					if ( zleadscrm_user_can_do_advanced_search( $current_user_id ) ) {
						$analytics['advanced_results']  = count( $name_items );
						$analytics['advanced_requests'] = $advanced_request;
					}

					if ( class_exists( 'ZLEADSCRM_ANALYTICS_Core' ) ) {
						zleadscrm_update_user_analytics( $analytics );
					}
				} else {
					if ( $this->query_params['city'] == '' || $this->query_params['state'] == '' || $this->query_params['search_term'] == '' ) {
						$this->items = [];
					} else {
						zleadscrm_delete_user_results( $current_user_id );
						delete_user_meta( $current_user_id, 'next_page_token' );
						$google_api_key      = get_option( 'zleadscrm_google_places_api_key' );
						$googlePlacesService = new GooglePlacesApiService( $google_api_key );
						$request_result      = json_decode( $googlePlacesService->getPlacesSearchResults( $this->query_params ) );
						$basic_request ++;
						$this->current_page_number = 1;

						if ( isset( $request_result->error_message ) || $request_result->error_message != '' ) {
							$this->error = $request_result->error_message;
						} else {
							if ( $request_result->status == 'ZERO_RESULTS' ) {
								$this->error = 'No Results found!';
							} else {
								if ( isset( $request_result->next_page_token ) && $request_result->next_page_token != '' ) {
									$this->set_next_page_token( $request_result->next_page_token );
								}
								$name_search_results = $request_result->results;
								$name_items          = [];

								foreach ( $name_search_results as $result ) {
									if ( zleadscrm_user_can_do_advanced_search( $current_user_id )
									     && zleadscrm_can_do_more_advanced_searches_this_month( $current_user_id, count( $name_items ) )
									     && zleadscrm_can_do_more_advanced_searches_this_week( $current_user_id, count( $name_items ) ) ) {
										$detailed_request = json_decode( $googlePlacesService->getPlacesDetailsResults( $result->place_id ) );
										$detailed_result  = $detailed_request->result;
										$advanced_request ++;

										$item = array(
											'business_name' => $result->name,
											'business_type' => $result->types,
											'phone'         => $detailed_result->international_phone_number,
											'website'       => $detailed_result->website,
											'address'       => $detailed_result->formatted_address,
											'url'           => $detailed_result->url
										);
										zleadscrm_upload_new_lead_result( array(
											'timestamp'     => current_time( 'mysql' ),
											'user_id'       => get_current_user_id(),
											'business_name' => $item['business_name'],
											'business_type' => $item['business_type'],
											'phone'         => $item['phone'],
											'website'       => $item['website'],
											'address'       => $item['address'],
											'url'           => $item['url']
										) );
									} else {
										$address_request = json_decode( $googlePlacesService->getPlaceAddressAndUrl( $result->place_id ) );

										$item = array(
											'business_name' => $result->name,
											'business_type' => $result->types,
											'address'       => $address_request->result->formatted_address,
											'url'           => $address_request->result->url
										);
										zleadscrm_upload_new_lead_result( array(
											'timestamp'     => current_time( 'mysql' ),
											'user_id'       => get_current_user_id(),
											'business_name' => $item['business_name'],
											'business_type' => $item['business_type'],
											'phone'         => '-',
											'website'       => '-',
											'address'       => $item['address'],
											'url'           => $item['url']
										) );
									}
									array_push( $name_items, $item );
								}

								$this->items = $name_items;
								$analytics   = array(
									'user_id'           => $current_user_id,
									'basic_requests'    => $basic_request,
									'basic_results'     => count( $name_items ),
									'timestamp'         => current_time( 'Y-m-d' ),
									'advanced_requests' => 0,
									'advanced_results'  => 0
								);

								if ( zleadscrm_user_can_do_advanced_search( $current_user_id ) ) {
									$analytics['advanced_results']  = count( $name_items );
									$analytics['advanced_requests'] = $advanced_request;
								}

								if ( class_exists( 'ZLEADSCRM_ANALYTICS_Core' ) ) {
									zleadscrm_update_user_analytics( $analytics );
								}
							}
						}
					}
				}
			}
		}

		public function is_bookmarked( $result ) {
			global $wpdb;
			$table_name    = $wpdb->prefix . 'zleadscrm_leads_bookmarks';
			$business_name = $result['business_name'];
			$business_type = '';
			if ( is_array( $result['business_type'] ) ) {
				foreach ( $result['business_type'] as $btype ) {
					$business_type .= ucfirst( str_replace( '_', ' ', $btype ) ) . ';';
				}
			} else {
				$business_type .= $result['business_type'];
			}

			$phone   = $result['phone'];
			$address = $result['address'];
			$website = $result['website'];
			$owner   = get_current_user_id();

			$results = $wpdb->get_results( "SELECT * FROM $table_name WHERE business_name='$business_name' AND business_type='$business_type' AND phone='$phone' AND address='$address' AND website='$website' AND owner_id=$owner LIMIT 1;" );

			if ( count( $results ) != 0 ) {
				return true;
			}

			return false;
		}

		public function get_next_page_token() {
			$max_results     = (int) get_option( 'zleadscrm_limit_call_number' );
			$current_results = $this->get_total_number_of_results();

			if ( $max_results > $current_results ) {
				return get_user_meta( get_current_user_id(), 'next_page_token', true );
			} else {
				return '';
			}

		}

		public function set_next_page_token( $next_page_token ) {
			$max_results     = (int) get_option( 'zleadscrm_limit_call_number' );
			$current_results = $this->get_total_number_of_results();

			if ( $max_results > $current_results ) {
				update_user_meta( get_current_user_id(), 'next_page_token', $next_page_token );
			} else {
				update_user_meta( get_current_user_id(), 'next_page_token', '' );
			}
		}

		public function add_next_page() {
			$token = $_POST['current_token'];

			if ( $token != '' ) {

				$link = 'admin.php?page=zleadscrm_leads';

				if ( isset( $_POST['search_term'] ) ) {
					$link .= '&search_term=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['search_term'] ) );
				}

				if ( isset( $_POST['business_type'] ) ) {
					$link .= '&business_type=' . sanitize_text_field( $_POST['business_type'] );
				}

				if ( isset( $_POST['city'] ) ) {
					$link .= '&city=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['city'] ) );
				}

				if ( isset( $_POST['state'] ) ) {
					$link .= '&state=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['state'] ) );
				}

				if ( isset( $_POST['miles'] ) ) {
					$link .= '&miles=' . (int) sanitize_text_field( $_POST['miles'] );
				}

				$link .= '&current_page=' . sanitize_text_field( $_POST['current_token'] );

				print( admin_url() . $link );
				exit();
			}
		}

		public function load_previous_page() {

			$link = 'admin.php?page=zleadscrm_leads';

			if ( isset( $_POST['search_term'] ) ) {
				$link .= '&search_term=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['search_term'] ) );
			}

			if ( isset( $_POST['business_type'] ) ) {
				$link .= '&business_type=' . sanitize_text_field( $_POST['business_type'] );
			}

			if ( isset( $_POST['city'] ) ) {
				$link .= '&city=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['city'] ) );
			}

			if ( isset( $_POST['state'] ) ) {
				$link .= '&state=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['state'] ) );
			}

			if ( isset( $_POST['miles'] ) ) {
				$link .= '&miles=' . (int) sanitize_text_field( $_POST['miles'] );
			}

			$link .= '&zleadscrm_paged=' . ( (int) sanitize_text_field( $_POST['current_page'] ) - 1 );

			print( admin_url() . $link );
			exit();
		}

		public function load_next_page() {

			$link = 'admin.php?page=zleadscrm_leads';

			if ( isset( $_POST['search_term'] ) ) {
				$link .= '&search_term=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['search_term'] ) );
			}

			if ( isset( $_POST['business_type'] ) ) {
				$link .= '&business_type=' . sanitize_text_field( $_POST['business_type'] );
			}

			if ( isset( $_POST['city'] ) ) {
				$link .= '&city=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['city'] ) );
			}

			if ( isset( $_POST['state'] ) ) {
				$link .= '&state=' . str_replace( ' ', '%20', sanitize_text_field( $_POST['state'] ) );
			}

			if ( isset( $_POST['miles'] ) ) {
				$link .= '&miles=' . (int) sanitize_text_field( $_POST['miles'] );
			}

			$link .= '&zleadscrm_paged=' . ( (int) sanitize_text_field( $_POST['current_page'] ) + 1 );

			print( admin_url() . $link );
			exit();
		}

		public function get_total_number_of_results() {
			global $wpdb;
			$table_name      = $wpdb->prefix . 'zleadscrm_leads_results';
			$current_user_id = get_current_user_id();
			$result          = $wpdb->get_results( "SELECT COUNT(*) AS results FROM $table_name WHERE user_id=$current_user_id;" );

			return $result[0]->results;
		}

	}

?>